==> Audit-DBI-1.7.3.tar.gz: Audit-DBI-1.7.3/README.md <==
Audit-DBI
========

[![Build Status](https://travis-ci.org/guillaumeaubert/Audit-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/Audit-DBI)

Audit data changes in your code and store searchable log records in a database.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Audit::DBI

You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Audit-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Audit-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Audit-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/Audit-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2010-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Audit-DBI-v1.8.2.tar.gz: Audit-DBI-v1.8.2/README.md <==
Audit-DBI
========

[![Build Status](https://travis-ci.org/guillaumeaubert/Audit-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/Audit-DBI)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Audit-DBI/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Audit-DBI?branch=master)

Audit data changes in your code and store searchable log records in a database.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Audit::DBI


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Audit-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Audit-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Audit-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/Audit-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2010-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
